# Copyright 2021 Variscite LTD
# SPDX-License-Identifier: BSD-3-Clause

CLASSIFICATION = "classification"
DETECTION = "detection"
SEGMENTATION = "segmentation"
